@@ -1,36 +1,34 @@
-from typing import Type
 from terminusgps.wialon import flags
 from terminusgps.wialon.items.base import WialonBase
 
 
 class WialonUnitGroup(WialonBase):
-    def create(self, **kwargs) -> int | None:
+    def create(self, creator_id: str | int, name: str) -> int | None:
         """
         Creates a new Wialon unit group.
 
         :param creator_id: A Wialon user id.
-        :type creator_id: :py:obj:`int`
+        :type creator_id: :py:obj:`str` | :py:obj:`int`
         :param name: A name for the group.
         :type name: :py:obj:`str`
+        :raises ValueError: If ``creator_id`` is not a digit.
         :raises WialonError: If something goes wrong with Wialon.
-        :returns: The Wialon id for the new group.
+        :returns: The Wialon id for the new group, if it was created.
         :rtype: :py:obj:`int` | :py:obj:`None`
 
         """
 
-        if not kwargs.get("creator_id"):
-            raise ValueError("'creator_id' is required on creation.")
-        if not kwargs.get("name"):
-            raise ValueError("'name' is required on creation.")
+        if isinstance(creator_id, str) and not creator_id.isdigit():
+            raise ValueError(f"'creator_id' must be a digit, got '{creator_id}'.")
 
         response = self.session.wialon_api.core_create_unit_group(
             **{
-                "creatorId": kwargs["creator_id"],
-                "name": kwargs["name"],
+                "creatorId": creator_id,
+                "name": name,
                 "dataFlags": flags.DATAFLAG_UNIT_BASE,
             }
         )
-        return response.get("item", {}).get("id")
+        return int(response.get("item", {}).get("id")) if response.get("item") else None
 
     def set_items(self, new_items: list[str]) -> None:
         """
@@ -48,7 +46,7 @@ class WialonUnitGroup(WialonBase):
             **{"itemId": self.id, "units": new_items}
         )
 
-    def is_member(self, item: Type[WialonBase]) -> bool:
+    def is_member(self, item: WialonBase) -> bool:
         """
         Determines whether or not ``item`` is a member of the group.
 
@@ -61,7 +59,7 @@ class WialonUnitGroup(WialonBase):
         """
         return True if str(item.id) in self.items else False
 
-    def add_item(self, item: Type[WialonBase]) -> None:
+    def add_item(self, item: WialonBase) -> None:
         """
         Adds a Wialon item to the group.
 
@@ -75,7 +73,7 @@ class WialonUnitGroup(WialonBase):
         new_items: list[str] = self.items.copy() + [str(item.id)]
         self.set_items(new_items)
 
-    def rm_item(self, item: Type[WialonBase]) -> None:
+    def rm_item(self, item: WialonBase) -> None:
         """
         Removes a Wialon unit from the group, if it's a member of the group.
 
@@ -117,3 +115,38 @@ class WialonUnitGroup(WialonBase):
             }
         )
         return [unit_id for unit_id in response.get("items")[0].get("u", [])]
+
+
+def main() -> None:
+    import logging
+
+    from django.utils import timezone
+    from django.conf import settings
+    from terminusgps.wialon.session import WialonSession
+    from terminusgps.wialon.items import WialonUnit
+    from terminusgps.wialon.utils import get_hw_type_id
+
+    timestamp = f"{timezone.now():%Y_%m_%d_%H:%M:%S}"
+    with WialonSession(log_level=logging.DEBUG) as session:
+        unit = WialonUnit(
+            id=None,
+            session=session,
+            creator_id=settings.WIALON_ADMIN_ID,
+            name=f"test_unit_{timestamp}",
+            hw_type_id=get_hw_type_id("Test HW", session=session),
+        )
+        group = WialonUnitGroup(
+            id=None,
+            session=session,
+            creator_id=settings.WIALON_ADMIN_ID,
+            name=f"test_group_{timestamp}",
+        )
+        group.add_item(unit)
+        print(f"{group.items = }")
+        unit.delete()
+        group.delete()
+    return
+
+
+if __name__ == "__main__":
+    main()
